@@ -1,11 +1,15 @@
 from moviebotapi.core.session import Session
 from moviebotapi.douban import DoubanApi
+from moviebotapi.meta import MetaApi
 from moviebotapi.notify import NotifyApi
 from moviebotapi.scraper import ScraperApi
 from moviebotapi.site import SiteApi
 from moviebotapi.subscribe import SubscribeApi
 from moviebotapi.tmdb import TmdbApi
 from moviebotapi.user import UserApi
+from moviebotapi.config import ConfigApi
+from moviebotapi.common import CommonApi
+from moviebotapi.amr import AmrApi
 
 
 class MovieBotServer:
@@ -16,12 +20,17 @@ class MovieBotServer:
     tmdb: TmdbApi
     site: SiteApi
     notify: NotifyApi
+    config: ConfigApi
+    meta: MetaApi
+    common: CommonApi
+    amr: AmrApi
 
     def __init__(self, session: Session = None):
         if session:
             self.set_session(session)
 
     def set_session(self, session: Session):
+        self.config = ConfigApi(session)
         self.user = UserApi(session)
         self.subscribe = SubscribeApi(session)
         self.scraper = ScraperApi(session)
@@ -29,3 +38,6 @@ class MovieBotServer:
         self.tmdb = TmdbApi(session)
         self.site = SiteApi(session)
         self.notify = NotifyApi(session)
+        self.meta = MetaApi(session)
+        self.common = CommonApi(session)
+        self.amr = AmrApi(session)
